==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/streamanalytics/kotlin/inputs/SkuArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.streamanalytics.kotlin.inputs

import com.pulumi.azurenative.streamanalytics.inputs.SkuArgs.builder
import com.pulumi.azurenative.streamanalytics.kotlin.enums.SkuName
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * The properties that are associated with a SKU.
 * @property name The name of the SKU. Required on PUT (CreateOrReplace) requests.
 */
public data class SkuArgs(
    public val name: Output<Either<String, SkuName>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.streamanalytics.inputs.SkuArgs> {
    override fun toJava(): com.pulumi.azurenative.streamanalytics.inputs.SkuArgs =
        com.pulumi.azurenative.streamanalytics.inputs.SkuArgs.builder()
            .name(
                name?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            ).build()
}

/**
 * Builder for [SkuArgs].
 */
@PulumiTagMarker
public class SkuArgsBuilder internal constructor() {
    private var name: Output<Either<String, SkuName>>? = null

    /**
     * @param value The name of the SKU. Required on PUT (CreateOrReplace) requests.
     */
    @JvmName("jqvymgklxwswtqdj")
    public suspend fun name(`value`: Output<Either<String, SkuName>>) {
        this.name = value
    }

    /**
     * @param value The name of the SKU. Required on PUT (CreateOrReplace) requests.
     */
    @JvmName("wnoxghyrifygbkgl")
    public suspend fun name(`value`: Either<String, SkuName>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.name = mapped
    }

    /**
     * @param value The name of the SKU. Required on PUT (CreateOrReplace) requests.
     */
    @JvmName("nokovoboqysilejo")
    public fun name(`value`: String) {
        val toBeMapped = Either.ofLeft<String, SkuName>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.name = mapped
    }

    /**
     * @param value The name of the SKU. Required on PUT (CreateOrReplace) requests.
     */
    @JvmName("yfbheirvfomrivja")
    public fun name(`value`: SkuName) {
        val toBeMapped = Either.ofRight<String, SkuName>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.name = mapped
    }

    internal fun build(): SkuArgs = SkuArgs(
        name = name,
    )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/streamanalytics/kotlin/inputs/SkuArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.streamanalytics.kotlin.inputs

import com.pulumi.azurenative.streamanalytics.inputs.SkuArgs.builder
import com.pulumi.azurenative.streamanalytics.kotlin.enums.SkuName
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * The properties that are associated with a SKU.
 * @property name The name of the SKU. Required on PUT (CreateOrReplace) requests.
 */
public data class SkuArgs(
    public val name: Output<Either<String, SkuName>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.streamanalytics.inputs.SkuArgs> {
    override fun toJava(): com.pulumi.azurenative.streamanalytics.inputs.SkuArgs =
        com.pulumi.azurenative.streamanalytics.inputs.SkuArgs.builder()
            .name(
                name?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            ).build()
}

/**
 * Builder for [SkuArgs].
 */
@PulumiTagMarker
public class SkuArgsBuilder internal constructor() {
    private var name: Output<Either<String, SkuName>>? = null

    /**
     * @param value The name of the SKU. Required on PUT (CreateOrReplace) requests.
     */
    @JvmName("piqrtmkusvuqxmhj")
    public suspend fun name(`value`: Output<Either<String, SkuName>>) {
        this.name = value
    }

    /**
     * @param value The name of the SKU. Required on PUT (CreateOrReplace) requests.
     */
    @JvmName("tdtoksbcikhwaxcg")
    public suspend fun name(`value`: Either<String, SkuName>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.name = mapped
    }

    /**
     * @param value The name of the SKU. Required on PUT (CreateOrReplace) requests.
     */
    @JvmName("pficwsaacydpwoge")
    public fun name(`value`: String) {
        val toBeMapped = Either.ofLeft<String, SkuName>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.name = mapped
    }

    /**
     * @param value The name of the SKU. Required on PUT (CreateOrReplace) requests.
     */
    @JvmName("pimxncqeqyuehtse")
    public fun name(`value`: SkuName) {
        val toBeMapped = Either.ofRight<String, SkuName>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.name = mapped
    }

    internal fun build(): SkuArgs = SkuArgs(
        name = name,
    )
}
